@@ -15,13 +15,21 @@ static PyMethodDef mod_methods[] = {
 };
 
 /* Python glue */
-PyObjC_MODULE_INIT(_AVKit)
+static struct PyModuleDef mod_module = {
+    PyModuleDef_HEAD_INIT, "_AVKit", NULL, 0, mod_methods, NULL, NULL, NULL, NULL};
+
+PyObject* PyInit__AVKit(void);
+
+PyObject* __attribute__((__visibility__("default"))) PyInit__AVKit(void)
 {
     PyObject* m;
-    m = PyObjC_MODULE_CREATE(_AVKit) if (!m) { PyObjC_INITERROR(); }
+    m = PyModule_Create(&mod_module);
+    if (!m) {
+        return NULL;
+    }
 
     if (PyObjC_ImportAPI(m) == -1)
-        PyObjC_INITERROR();
+        return NULL;
 
-    PyObjC_INITDONE();
+    return m;
 }
